import os
import tempfile
import unittest
from pathlib import Path
from unittest.mock import patch

from automio.wrapper import API, FilesApi


class TestWrapperFilesApi(unittest.TestCase):
    def test_api_exposes_files_api(self) -> None:
        with patch.dict(os.environ, {"APP_ID": "180"}, clear=False):
            api = API()
            self.assertIsInstance(api.files, FilesApi)

    def test_upload_uses_env_app_id(self) -> None:
        with patch.dict(os.environ, {"APP_ID": "180"}, clear=False):
            api = API()
            with patch.object(
                FilesApi,
                "apps_files_upload_create",
                return_value="uploaded",
            ) as mocked_upload:
                result = api.files.upload(
                    file=("report.txt", b"hello"),
                    path="exports/report.txt",
                    overwrite=True,
                )

        self.assertEqual(result, "uploaded")
        mocked_upload.assert_called_once_with(
            id=180,
            file=("report.txt", b"hello"),
            path="exports/report.txt",
            overwrite=True,
        )

    def test_upload_accepts_pathlike(self) -> None:
        with tempfile.NamedTemporaryFile(delete=False, suffix=".txt") as tmp_file:
            tmp_file.write(b"hello world")
            tmp_path = Path(tmp_file.name)

        try:
            with patch.dict(os.environ, {"APP_ID": "180"}, clear=False):
                api = API()
                with patch.object(
                    FilesApi,
                    "apps_files_upload_create",
                    return_value="uploaded",
                ) as mocked_upload:
                    api.files.upload(file=tmp_path, path="exports/report.txt")

            mocked_upload.assert_called_once()
            self.assertEqual(mocked_upload.call_args.kwargs["id"], 180)
            uploaded_file = mocked_upload.call_args.kwargs["file"]
            self.assertEqual(uploaded_file[0], tmp_path.name)
            self.assertEqual(uploaded_file[1], b"hello world")
        finally:
            tmp_path.unlink(missing_ok=True)

    def test_download_uses_env_app_id(self) -> None:
        with patch.dict(os.environ, {"APP_ID": "180"}, clear=False):
            api = API()
            with patch.object(
                FilesApi,
                "apps_files_download_retrieve",
                return_value="downloaded",
            ) as mocked_download:
                result = api.files.download("exports/report.txt")

        self.assertEqual(result, "downloaded")
        mocked_download.assert_called_once_with(id=180, path="exports/report.txt")

    def test_download_requires_integer_app_id(self) -> None:
        with patch.dict(os.environ, {"APP_ID": "org-slug/app-slug"}, clear=False):
            api = API()
            with self.assertRaisesRegex(ValueError, "app_id must be an integer"):
                api.files.download("exports/report.txt")


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.application_file_download_response import ApplicationFileDownloadResponse

class TestApplicationFileDownloadResponse(unittest.TestCase):
    """ApplicationFileDownloadResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationFileDownloadResponse:
        """Test ApplicationFileDownloadResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationFileDownloadResponse`
        """
        model = ApplicationFileDownloadResponse()
        if include_optional:
            return ApplicationFileDownloadResponse(
                bucket_name = '',
                path = '',
                object_key = '',
                public_url = ''
            )
        else:
            return ApplicationFileDownloadResponse(
                bucket_name = '',
                path = '',
                object_key = '',
                public_url = '',
        )
        """

    def testApplicationFileDownloadResponse(self):
        """Test ApplicationFileDownloadResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.get_integrations200_response_results_inner_one_of import GetIntegrations200ResponseResultsInnerOneOf

class TestGetIntegrations200ResponseResultsInnerOneOf(unittest.TestCase):
    """GetIntegrations200ResponseResultsInnerOneOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetIntegrations200ResponseResultsInnerOneOf:
        """Test GetIntegrations200ResponseResultsInnerOneOf
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetIntegrations200ResponseResultsInnerOneOf`
        """
        model = GetIntegrations200ResponseResultsInnerOneOf()
        if include_optional:
            return GetIntegrations200ResponseResultsInnerOneOf(
                count = 56,
                next = '',
                previous = '',
                results = [
                    { }
                    ]
            )
        else:
            return GetIntegrations200ResponseResultsInnerOneOf(
                count = 56,
                results = [
                    { }
                    ],
        )
        """

    def testGetIntegrations200ResponseResultsInnerOneOf(self):
        """Test GetIntegrations200ResponseResultsInnerOneOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.get_integrations200_response import GetIntegrations200Response

class TestGetIntegrations200Response(unittest.TestCase):
    """GetIntegrations200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetIntegrations200Response:
        """Test GetIntegrations200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetIntegrations200Response`
        """
        model = GetIntegrations200Response()
        if include_optional:
            return GetIntegrations200Response(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    null
                    ]
            )
        else:
            return GetIntegrations200Response(
                count = 123,
                results = [
                    null
                    ],
        )
        """

    def testGetIntegrations200Response(self):
        """Test GetIntegrations200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.api.applications_files_api import ApplicationsFilesApi


class TestApplicationsFilesApi(unittest.TestCase):
    """ApplicationsFilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsFilesApi()

    def tearDown(self) -> None:
        pass

    def test_apps_files_download_retrieve(self) -> None:
        """Test case for apps_files_download_retrieve

        Resolve application file URL
        """
        pass

    def test_apps_files_upload_create(self) -> None:
        """Test case for apps_files_upload_create

        Upload application file
        """
        pass


if __name__ == '__main__':
    unittest.main()
